@@ -45,7 +45,9 @@ import typing_extensions
 from ._jsii import *
 
 import aws_cdk.aws_certificatemanager
+import aws_cdk.aws_iam
 import aws_cdk.aws_route53
+import aws_cdk.aws_sqs
 import aws_cdk.core
 import constructs
 
@@ -117,6 +119,7 @@ class AlarmActions:
         )
 
 
+@jsii.implements(aws_cdk.aws_iam.IGrantable)
 class ConstructHub(
     aws_cdk.core.Construct,
     metaclass=jsii.JSIIMeta,
@@ -151,6 +154,23 @@ class ConstructHub(
 
         jsii.create(ConstructHub, self, [scope, id, props])
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="grantPrincipal")
+    def grant_principal(self) -> aws_cdk.aws_iam.IPrincipal:
+        '''(experimental) The principal to grant permissions to.
+
+        :stability: experimental
+        '''
+        return typing.cast(aws_cdk.aws_iam.IPrincipal, jsii.get(self, "grantPrincipal"))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="ingestionQueue")
+    def ingestion_queue(self) -> aws_cdk.aws_sqs.IQueue:
+        '''
+        :stability: experimental
+        '''
+        return typing.cast(aws_cdk.aws_sqs.IQueue, jsii.get(self, "ingestionQueue"))
+
 
 @jsii.data_type(
     jsii_type="construct-hub.ConstructHubProps",
